searchData={"items":[{"type":"module","title":"Exposure","doc":"`Exposure` adds support for snapshot testing to Elixir projects.\n\nFor more information, see [Usage](README.md#usage).","ref":"Exposure.html"},{"type":"macro","title":"Exposure.test_snapshot/2","doc":"Defines a snapshot test.","ref":"Exposure.html#test_snapshot/2"},{"type":"macro","title":"Examples - Exposure.test_snapshot/2","doc":"```elixir\ndescribe \"my_fun/2\" do\n  test_snapshot \"works as expected\" do\n    my_fun(\"foo\", 123)\n  end\nend\n```","ref":"Exposure.html#test_snapshot/2-examples"},{"type":"macro","title":"Exposure.test_snapshot/3","doc":"Defines a snapshot test that utilizes the test context.","ref":"Exposure.html#test_snapshot/3"},{"type":"macro","title":"Examples - Exposure.test_snapshot/3","doc":"```elixir\ndescribe \"my_fun/3\" do\n  test_snapshot \"works as expected\", ctx do\n    my_fun(\"foo\", 123, ctx)\n  end\nend\n```","ref":"Exposure.html#test_snapshot/3-examples"},{"type":"extras","title":"Exposure","doc":"# Exposure\n\n![CI](https://github.com/gdwoolbert3/exposure/actions/workflows/ci.yml/badge.svg)\n[![Package](https://img.shields.io/hexpm/v/exposure.svg)](https://hex.pm/packages/exposure)\n\n`Exposure` is a simple and leightweight snapshot testing library for Elixir","ref":"readme.html"},{"type":"extras","title":"Installation - Exposure","doc":"This package can be installed by adding `:exposure` to your list of dependencies\nin `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:exposure, \"~> 1.1.0\", only: [:dev, :test]}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - Exposure","doc":"For additional documentation, see [HexDocs](https://hexdocs.pm/exposure/readme.html).","ref":"readme.html#documentation"},{"type":"extras","title":"Usage - Exposure","doc":"`Exposure` is easy to use and is designed to integrate seamlessly with Elixir's\n`ExUnit` module.","ref":"readme.html#usage"},{"type":"extras","title":"Defining Snapshot Tests - Exposure","doc":"Snapshot tests can be defined with the `test_snapshot` macro. This macro is\nsyntactically similar to the normal `test` macro and interacts with other\n`ExUnit` entities in the same way.\n\n```elixir\ndefmodule SampleTest do\n  use ExUnit.Case\n\n  import Exposure\n\n  setup_all do\n    %{foo: 1, bar: 2}\n  end\n\n  describe \"Map.put/3\" do\n    @tag :sample_tag\n    test_snapshot \"will add a new pair to a map\", ctx do\n      ctx\n      |> Map.put(:baz, 3)\n      |> Map.take([:foo, :bar, :baz])\n    end\n  end\nend\n```","ref":"readme.html#defining-snapshot-tests"},{"type":"extras","title":"Updating Snapshot Files - Exposure","doc":"Once a snapshot test is defined, a snapshot file can be generated by running the\ntest with the `EXPOSURE_OVERRIDE` flag set to `true`:\n\n```bash\nEXPOSURE_OVERRIDE=true mix test test/sample_test.exs:12\n```\n\n`Exposure` creates a snapshot directory for each test path and a snapshot file\nfor each test. The snapshot directory structure mirrors the test path directory\nstructure. For the example snapshot test above, the command would generate a\nfile at the following location:\n\n```\ntest/_snapshots/sample_test/test_map_put_3_will_add_a_new_pair_to_a_map.snap\n```\n\nProjects using `Exposure` can also leverage the configured  `:snapshot_test_tag`\nto create a custom alias for generating snapshots:\n\n```elixir\ndefmodule MyApp.MixProject do\n  use Mix.Project\n\n  def project do\n    [\n      aliases: [\"snapshots.generate\": &generate_snapshots/1],\n      preferred_cli_env: [\"snapshots.generate\": :test],\n      ...\n    ]\n  end\n\n  defp generate_snapshots(args) do\n    System.put_env(\"EXPOSURE_OVERRIDE\", \"true\")\n    args = [\"--only\", \"snapshot\"] ++ args\n    Mix.Tasks.Test.run(args)\n  end\n\n  ...\nend\n```","ref":"readme.html#updating-snapshot-files"},{"type":"extras","title":"Running Snapshot Tests - Exposure","doc":"Once a snapshot file has been created, a snapshot test can be run in the same\nway as a normal test:\n\n```bash\nmix test test/sample_test.exs:12\n```","ref":"readme.html#running-snapshot-tests"},{"type":"extras","title":"Configuration - Exposure","doc":"`Exposure` has a few few configuration options that can be set in the\napplication config:\n\n```elixir\n# In config/test.exs\nconfig :exposure,\n  snapshot_directory: \"my_snapshot_dir\",\n  snapshot_test_tag: :my_test_tag\n```\n\nMore specifically, the configuration options are:\n\n* `:snapshot_directory` - A `t:binary/0` denoting the name of the snapshot\n  directory. Defaults to `_snapshots`.\n\n* `:snapshot_test_tag` - An `t:atom/0` denoting the tag that `Exposure` uses\n  to differentiate snapshot tests. Defaults to `:snapshot`.","ref":"readme.html#configuration"},{"type":"extras","title":"Test Paths - Exposure","doc":"`Exposure` can also be used for projects with non-traditional test paths. For\nmore information on how to configure multiple test paths, see the `mix test`\n[docs](https://hexdocs.pm/mix/1.12/Mix.Tasks.Test.html#module-configuration).\n\nIn general, `Exposure` creates a separate snapshot directory for each test path.\nThe only exception is if one test path contains another. In that case, a\nsnapshot directory is only created in the parent path. For example, consider a\nproject with the following configuration:\n\n```elixir\n# In mix.exs\ndef project do\n  [\n    test_paths: [\"test\", \"other_test\", \"other_test/dir\"]\n  ]\nend\n```\n\n`Exposure` would only create two snapshot directories for the above project:\n\n```\ntest/_snapshots\nother_test/_snapshots\n```\n\n`Exposure` requires that all snapshot tests exist within one of the project test\npaths. In conjunction with the above simplification, this constraint guarantees\na consistent snapshot file location for every test.","ref":"readme.html#test-paths"},{"type":"extras","title":"Other Libraries - Exposure","doc":"The `Exposure` API is heavily inspired by the\n[`Snapshy`](https://github.com/DCzajkowski/snapshy) library. For the vast\nmajority of cases, `Snapshy` is more than sufficient. The main differences are\nrelatively niche:\n\n* `Exposure` has explicit support for additional test paths.\n\n* `Exposure` has slightly different naming rules for snapshot files.\n\n* `Exposure` requires a snapshot to exist before running a test.\n\nIf those differences are unimportant for your project, `Snapshy` may be a better\nchoice.\n\nAdditionally, no discussion of snapshot testing in Elixir would be complete\nwithout mentioning the\n[`assert_value`](https://github.com/assert-value/assert_value_elixir) package.\nThe concept of a snapshot is handled slightly differently in `assert_value` but\nthe library is robust and mature and definitely worth investigating.","ref":"readme.html#other-libraries"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\n\n## [1.1.0] - 2025-05-23","ref":"changelog.html"},{"type":"extras","title":"Changed - Change Log","doc":"* Umbrella project bugfixes","ref":"changelog.html#changed"},{"type":"extras","title":"Links - Change Log","doc":"* [GitHub](https://github.com/gdwoolbert3/exposure/releases/tag/v1.1.0)\n* [HexDocs](https://hexdocs.pm/exposure/1.1.0/readme.html)\n\n## [1.0.0] - 2025-01-29","ref":"changelog.html#links"},{"type":"extras","title":"Changed - Change Log","doc":"* Initial implementation","ref":"changelog.html#changed"},{"type":"extras","title":"Links - Change Log","doc":"* [GitHub](https://github.com/gdwoolbert3/exposure/releases/tag/v1.0.0)\n* [HexDocs](https://hexdocs.pm/exposure/1.0.0/readme.html)","ref":"changelog.html#links"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}